<?php

/**
 * @file
 *   List pages for the advanced_page
 */
function page_manager_list() {
  return _node_table();
}

/**
 * Function for displaying table
 */
function _node_table() {
  //Create a list of headers for your Html table (see Drupal 7 docs for theme_table here
  $header = array(
    array('data' => t('Title'), 'field' => 'title', 'sort' => 'asc'),
    array('data' => t('Node ID'), 'field' => 'nid'),
    array('data' => t('Type'), 'field' => 'type'),
    array('data' => t('Created'), 'field' => 'created'),
    array('data' => t('Published')),
    array('data' => t('Action')),
  );

//Create the Sql query. This uses various parts of Drupal 7's new DBTNG database abstraction layer.

  $query = db_select('node', 'n')
      ->condition('type', 'advanced_page', '=') //Only published nodes, change condition as it suits you
      ->extend('PagerDefault')  //Pager Extender
      ->limit(50)    //10 results per page
      ->extend('TableSort')  //Sorting Extender
      ->orderByHeader($header)//Field to sort on is picked from $header
      ->fields('n', array(
    'nid',
    'title',
    'type',
    'created',
    'status',
      ));

  $results = $query->execute();

  $rows = array();
  foreach ($results as $node) {
    $rows[] = array(
      'data' => array(
        l($node->title, 'node/' . $node->nid . '/edit'),
        $node->nid,
        $node->type,
        format_date($node->created),
        $node->status ? "Yes" : "No",
        l(t("edit"), 'node/' . $node->nid . '/edit'),
      )
    );
  }

//Theme the html table
  $html = theme('table', array(
    'header' => $header,
    'rows' => $rows,
    'caption' => 'List of static pages', //Optional Caption for the table
    'sticky' => TRUE, //Optional to indicate whether the table headers should be sticky
    'empty' => 'No nodes created...', //Optional empty text for the table if resultset is empty
      )
  );

//Append pager
  $html .= theme('pager', array(
    'tags' => array()
      )
  );

  return ($html);
}
